# Generated by roxygen2: do not edit by hand

S3method(as_gt,gsBinomialExactTable)
S3method(as_rtf,gsBinomialExactTable)
S3method(as_rtf,gsBoundSummary)
S3method(as_table,gsBinomialExact)
S3method(plot,binomialSPRT)
S3method(plot,gsBinomialExact)
S3method(plot,gsDesign)
S3method(plot,gsProbability)
S3method(plot,ssrCP)
S3method(print,eEvents)
S3method(print,gsBoundSummary)
S3method(print,gsDesign)
S3method(print,gsProbability)
S3method(print,gsSurv)
S3method(print,nSurv)
S3method(print,nSurvival)
S3method(summary,gsDesign)
S3method(summary,spendfn)
S3method(xtable,gsDesign)
S3method(xtable,gsSurv)
export(Power.ssrCP)
export(as_gt)
export(as_rtf)
export(as_table)
export(binomialPowerTable)
export(binomialSPRT)
export(checkLengths)
export(checkRange)
export(checkScalar)
export(checkVector)
export(ciBinomial)
export(condPower)
export(eEvents)
export(gsBValue)
export(gsBinomialExact)
export(gsBound)
export(gsBound1)
export(gsBoundCP)
export(gsBoundSummary)
export(gsCP)
export(gsCPOS)
export(gsCPz)
export(gsDelta)
export(gsDensity)
export(gsDesign)
export(gsHR)
export(gsPI)
export(gsPOS)
export(gsPP)
export(gsPosterior)
export(gsProbability)
export(gsRR)
export(gsSurv)
export(gsSurvCalendar)
export(gsSurvPower)
export(hrn2z)
export(hrz2n)
export(isInteger)
export(nBinomial)
export(nBinomial1Sample)
export(nEvents)
export(nEventsIA)
export(nNormal)
export(nSurv)
export(nSurvival)
export(normalGrid)
export(repeatedPValueBinomialExact)
export(sequentialPValue)
export(sequentialPValueBinomialExact)
export(sfBetaDist)
export(sfCauchy)
export(sfExponential)
export(sfExtremeValue)
export(sfExtremeValue2)
export(sfGapped)
export(sfHSD)
export(sfLDOF)
export(sfLDPocock)
export(sfLinear)
export(sfLogistic)
export(sfNormal)
export(sfPoints)
export(sfPower)
export(sfStep)
export(sfTDist)
export(sfTrimmed)
export(sfTruncated)
export(sfXG1)
export(sfXG2)
export(sfXG3)
export(simBinomial)
export(simBinomialSeasonalExact)
export(spendingFunction)
export(ssrCP)
export(tEventsIA)
export(testBinomial)
export(toBinomialExact)
export(toInteger)
export(varBinomial)
export(xprint)
export(xtable)
export(z2Fisher)
export(z2NC)
export(z2Z)
export(zn2hr)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,reframe)
importFrom(dplyr,select)
importFrom(dplyr,summarize)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,qplot)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_linetype_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(graphics,axis)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,matplot)
importFrom(graphics,matpoints)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,strwidth)
importFrom(graphics,text)
importFrom(gt,cols_label)
importFrom(gt,fmt_number)
importFrom(gt,fmt_percent)
importFrom(gt,gt)
importFrom(gt,html)
importFrom(gt,tab_header)
importFrom(gt,tab_spanner)
importFrom(methods,is)
importFrom(r2rtf,rtf_body)
importFrom(r2rtf,rtf_colheader)
importFrom(r2rtf,rtf_encode)
importFrom(r2rtf,rtf_footnote)
importFrom(r2rtf,rtf_title)
importFrom(r2rtf,write_rtf)
importFrom(rlang,.data)
importFrom(stats,dnorm)
importFrom(stats,nlminb)
importFrom(stats,pbeta)
importFrom(stats,pbinom)
importFrom(stats,pcauchy)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,pt)
importFrom(stats,qbinom)
importFrom(stats,qcauchy)
importFrom(stats,qchisq)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,rbinom)
importFrom(stats,reshape)
importFrom(stats,setNames)
importFrom(stats,uniroot)
importFrom(tibble,as_tibble)
importFrom(tidyr,pivot_longer)
importFrom(xtable,xtable)
useDynLib(gsDesign,gsbound)
useDynLib(gsDesign,gsbound1)
useDynLib(gsDesign,gsdensity)
useDynLib(gsDesign,probrej)
useDynLib(gsDesign,stdnorpts)
