---
title: "Multiplicity graphs"
output: rmarkdown::html_vignette
bibliography: gsDesign.bib
vignette: >
  %\VignetteIndexEntry{Multiplicity graphs}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

The content of this vignette has been moved to the gMCPLite package: <https://merck.github.io/gMCPLite/articles/hGraph.html>.
