---
title: "Graphical testing for group sequential design"
output: rmarkdown::html_vignette
bibliography: gsDesign.bib
vignette: >
  %\VignetteIndexEntry{Graphical testing for group sequential design}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

The content of this vignette has been moved to the gMCPLite package: <https://merck.github.io/gMCPLite/articles/GraphicalMultiplicity.html>.
